<img src="https://sun1-1.userapi.com/c830708/v830708875/1b85e9/6fnZeL3jWqw.jpg" alt="drawing" width="200"/>

Svist4get is a simple bioinformatics tool for visualization of genomic signal tracks in user-defined genomic windows, either arbitrary selected by genomic coordinates or anchored to particular transcripts or genes.

See the documentation in the Home page.
